@@ -1,5 +1,9 @@
+import numpy
+import os
 
-import cmor_const,numpy,os,_cmor
+import cmor_const
+import _cmor
+from _cmor import CMORError
 
 try:
     import cdtime
@@ -33,43 +37,49 @@ def time_varying_grid_coordinate(grid_id, table_entry,units,type='f',missing_val
     grid_id : The grid_id return by a call to cmor.grid
     table_entry: The name of the variable in the CMOR table
     units: variable units
-    type: type of the missing_value, which must be the same as the type of the array  that will be passed to cmor_write.  The options are: 'd' (double), 'f' (float), 'l' (long) or 'i' (int).
-    missing_value : scalar that is used to indicate missing data for this variable.  It must be the same type as the data that will be passed to cmor_write.  This missing_value will in general be replaced by a standard missing_value specified in the MIP table.  If there are no missing data, and the user chooses not to declare the missing value, then this argument may be either omitted or assigned the value 'none' (i.e., missing_value='none').
+    type: type of the missing_value, which must be the same as the type of the array  that will be passed to cmor_write.
+    The options are: 'd' (double), 'f' (float), 'l' (long) or 'i' (int).
+    missing_value : scalar that is used to indicate missing data for this variable.
+    It must be the same type as the data that will be passed to cmor_write.
+    This missing_value will in general be replaced by a standard missing_value specified in the MIP table.
+    If there are no missing data, and the user chooses not to declare the missing value, then this argument may be either
+    omitted or assigned the value 'none' (i.e., missing_value='none').
     """
-    if not isinstance(table_entry,str):
+    if not isinstance(table_entry, str):
         raise Exception, "Error you must pass a string for the variable table_entry"
-    
-    if not isinstance(units,str):
+
+    if not isinstance(units, str):
         raise Exception, "Error you must pass a string for the variable units"
-    if not isinstance(type,str):
+    if not isinstance(type, str):
         raise Exception, "error tpye must a a string"
     type = type.lower()
     if type == 's':
-        type ='c'
-    if not type in ["c","d","f","l","i"]:
+        type = 'c'
+    if type not in ["c", "d", "f", "l", "i"]:
         raise Exception, 'error unknown type: "%s", must be one of: "c","d","f","l","i"'
 
-    if not isinstance(grid_id,(int,numpy.int,numpy.int32)):
+    if not isinstance(grid_id, (int, numpy.int, numpy.int32)):
         raise Exception, "error grid_id must be an integer"
+        
     grid_id = int(grid_id)
 
     if missing_value is not None:
-        if not isinstance(missing_value,(float,int,numpy.float,numpy.float32,numpy.int,numpy.int32)):
+        if not isinstance(missing_value, (float, int, numpy.float, numpy.float32, numpy.int, numpy.int32)):
             raise Exception, "error missing_value must be a number, you passed: %s" % type(missing_value)
         missing_value = float(missing_value)
-        
-    return _cmor.time_varying_grid_coordinate(grid_id,table_entry,units,type,missing_value)
-    
+
+    return _cmor.time_varying_grid_coordinate(grid_id, table_entry, units, type, missing_value)
+
 
 def _to_numpy(vals, message):
     if isinstance(vals, (list, tuple)):
         vals = numpy.ascontiguousarray(vals)
-    elif not isinstance(vals,numpy.ndarray):
+    elif not isinstance(vals, numpy.ndarray):
         try:
             vals = numpy.ascontiguousarray(vals.filled())
         except:
             raise Exception, "Error could not convert %s to a numpy array" % message
-        
+
     return vals
 
 def grid(axis_ids,latitude=None,longitude=None,latitude_vertices=None,longitude_vertices=None,nvertices=None):
@@ -94,13 +104,13 @@ def grid(axis_ids,latitude=None,longitude=None,latitude_vertices=None,longitude_
     elif not isinstance(axis_ids, numpy.ndarray):
         raise Exception, "Error could not convert axis_ids list to a numpy array"
 
-    if numpy.rank(axis_ids)>1:
+    if numpy.ndim(axis_ids)>1:
         raise Exception, "error axes list/array must be 1D"
 
     if latitude is not None:
         latitude = _to_numpy(latitude, 'latitude')
-            
-        if numpy.rank(latitude)!=len(axis_ids):
+
+        if numpy.ndim(latitude)!=len(axis_ids):
             raise Exception, "latitude's rank does not match number of axes passed via axis_ids"
 
         type = latitude.dtype.char
@@ -110,9 +120,9 @@ def grid(axis_ids,latitude=None,longitude=None,latitude_vertices=None,longitude_
 
         longitude = _to_numpy(longitude, 'longitude')
 
-        if numpy.rank(longitude)!=len(axis_ids):
+        if numpy.ndim(longitude)!=len(axis_ids):
             raise Exception, "longitude's rank does not match number of axes passed via axis_ids"
-        
+
     ##     print 'longitude type:',longitude.dtype.char
         if longitude.dtype.char!=type:
             longitude = longitude.astype(type)
@@ -124,11 +134,11 @@ def grid(axis_ids,latitude=None,longitude=None,latitude_vertices=None,longitude_
             nvert=0
         else:
             nvert = nvertices
-        
+
     if latitude_vertices is not None:
         latitude_vertices = _to_numpy(latitude_vertices, 'latitude_vertices')
 
-        if numpy.rank(latitude_vertices)!=len(axis_ids)+1:
+        if numpy.ndim(latitude_vertices)!=len(axis_ids)+1:
             raise Exception, "latitude_vertices's rank does not match number of axes passed via axis_ids +1 (for vertices)"
 ##         print 'latitude_vert type:',latitude_vertices.dtype.char
         if latitude_vertices.dtype.char!=type:
@@ -137,10 +147,10 @@ def grid(axis_ids,latitude=None,longitude=None,latitude_vertices=None,longitude_
         if nvertices is not None:
             if nvert!=nvertices:
                 raise Exception,"you passed nvertices as: %i, but from your latitude_vertices it seems to be: %i" % (nvertices,nvert)
-        
+
     if longitude_vertices is not None:
         longitude_vertices = _to_numpy(longitude_vertices, 'longitude_vertices')
-        if numpy.rank(longitude_vertices)!=len(axis_ids)+1:
+        if numpy.ndim(longitude_vertices)!=len(axis_ids)+1:
             raise Exception, "longitude_vertices's rank does not match number of axes passed via axis_ids +1 (for vertices)"
 ##         print 'longitude_vert type:',longitude_vertices.dtype.char
         if longitude_vertices.dtype.char!=type:
@@ -154,7 +164,7 @@ def grid(axis_ids,latitude=None,longitude=None,latitude_vertices=None,longitude_
             if nvert!=nvertices:
                 raise Exception,"you passed nvertices as: %i, but from your longitude_vertices it seems to be: %i" % (nvertices,nvert)
 
-        
+
 ##     if area is not None:
 ##         if not isinstance(area,numpy.ndarray):
 ##             try:
@@ -240,7 +250,7 @@ def set_grid_mapping(grid_id,mapping_name,parameter_names,parameter_values=None,
     pvals = numpy.ascontiguousarray(pvals).astype('d')
     return _cmor.set_grid_mapping(grid_id,mapping_name,pnms,pvals,punit)
 
-    
+
 
 def axis(table_entry,units=None,length=None,coord_vals=None,cell_bounds=None,interval=None):
     """ Creates an cmor_axis
@@ -288,7 +298,7 @@ def axis(table_entry,units=None,length=None,coord_vals=None,cell_bounds=None,int
         if not isinstance(coord_vals,numpy.ndarray):
             raise Exception, "Error coord_vals must be an array or cdms2 axis or list/tuple"
 
-        if numpy.rank(coord_vals)>1:
+        if numpy.ndim(coord_vals)>1:
             raise Exception, "Error, you must pass a 1D array!"
 
     if numpy.ma.isMA(cell_bounds):
@@ -301,11 +311,11 @@ def axis(table_entry,units=None,length=None,coord_vals=None,cell_bounds=None,int
         cell_bounds = numpy.ascontiguousarray(cell_bounds.filled())
     elif isinstance(cell_bounds,(list,tuple)):
         cell_bounds = numpy.ascontiguousarray(cell_bounds)
-        
+
     if cell_bounds is not None:
-        if numpy.rank(cell_bounds)>2:
+        if numpy.ndim(cell_bounds)>2:
             raise Exception, "Error cell_bounds rank must be at most 2"
-        if numpy.rank(cell_bounds)==2:
+        if numpy.ndim(cell_bounds)==2:
             if cell_bounds.shape[0]!=coord_vals.shape[0]:
                 raise Exception, "Error, coord_vals and cell_bounds do not have the same length"
             if cell_bounds.shape[1]!=2:
@@ -337,30 +347,30 @@ def axis(table_entry,units=None,length=None,coord_vals=None,cell_bounds=None,int
     else:
         l = 0
         type = 'd'
-        
+
     if cell_bounds is not None:
         if type !=cell_bounds.dtype.char:
             cell_bounds = cell_bounds.astype(type)
-            
+
     if units is None:
         if coord_vals is not None:
             raise Exception, "Error you need to provide the units your coord_vals are in"
         else:
             units = "1"
-    
+
     if interval is None:
         interval = ""
 
     if length is not None:
         l = int(length)
-        
+
     return _cmor.axis(table_entry,units,l,coord_vals,type,cell_bounds,cbnds,interval)
 
 def variable(table_entry,units,axis_ids,type='f',missing_value=None,tolerance = 1.e-4,positive=None,original_name=None,history=None,comment=None):
-    
+
     if not isinstance(table_entry,str):
         raise Exception, "Error you must pass a string for the variable table_entry"
-    
+
     if not isinstance(units,str):
         raise Exception, "Error you must pass a string for the variable units"
 
@@ -369,19 +379,19 @@ def variable(table_entry,units,axis_ids,type='f',missing_value=None,tolerance =
             raise Exception, "Error you must pass a string for the variable original_name"
     else:
         original_name = ""
-        
+
     if history is not None:
         if not isinstance(history,str):
             raise Exception, "Error you must pass a string for the variable history"
     else:
         history = ""
-        
+
     if comment is not None:
         if not isinstance(comment,str):
             raise Exception, "Error you must pass a string for the variable comment"
     else:
         comment = ""
-        
+
     if numpy.ma.isMA(axis_ids):
         axis_ids = numpy.ascontiguousarray(axis_ids.filled())
     elif has_oldma and numpy.oldnumeric.ma.isMA(axis_ids):
@@ -393,7 +403,7 @@ def variable(table_entry,units,axis_ids,type='f',missing_value=None,tolerance =
     elif not isinstance(axis_ids, numpy.ndarray):
         raise Exception, "Error could not convert axis_ids list to a numpy array"
 
-    if numpy.rank(axis_ids)>1:
+    if numpy.ndim(axis_ids)>1:
         raise Exception, "error axis_ids list/array must be 1D"
 
     if not isinstance(type,str):
@@ -434,7 +444,7 @@ def variable(table_entry,units,axis_ids,type='f',missing_value=None,tolerance =
 
     axis_ids=axis_ids.astype('i')
     return _cmor.variable(table_entry,units,ndims,axis_ids,type,missing_value,tolerance,positive,original_name,history,comment)
-    
+
 def zfactor(zaxis_id,zfactor_name,units="",axis_ids=None,type=None,zfactor_values=None,zfactor_bounds=None):
 
     if not isinstance(zaxis_id,(int,numpy.int,numpy.int32)):
@@ -443,7 +453,7 @@ def zfactor(zaxis_id,zfactor_name,units="",axis_ids=None,type=None,zfactor_value
 
     if not isinstance(zfactor_name,str):
         raise Exception, "Error you must pass a string for the variable zfactor_name"
-    
+
     if not isinstance(units,str):
         raise Exception, "Error you must pass a string for the variable units"
 
@@ -464,7 +474,7 @@ def zfactor(zaxis_id,zfactor_name,units="",axis_ids=None,type=None,zfactor_value
     elif not isinstance(axis_ids, numpy.ndarray):
         raise Exception, "Error could not convert axis_ids list to a numpy array"
 
-    if numpy.rank(axis_ids)>1:
+    if numpy.ndim(axis_ids)>1:
         raise Exception, "error axis_ids list/array must be 1D"
 
     if axis_ids is None:
@@ -504,8 +514,8 @@ def zfactor(zaxis_id,zfactor_name,units="",axis_ids=None,type=None,zfactor_value
                     raise Exception, "Error unknown type for zfactor_values: %s" % repr(zfactor_values)
     elif type is None:
         type='d'
-        
-        
+
+
     if not isinstance(type,str):
         raise Exception, "error tpye must a a string"
     type = type.lower()
@@ -513,7 +523,7 @@ def zfactor(zaxis_id,zfactor_name,units="",axis_ids=None,type=None,zfactor_value
         type ='c'
     if not type in ["c","d","f","l","i"]:
         raise Exception, 'error unknown type: "%s", must be one of: "c","d","f","l","i"'
-    
+
     if zfactor_bounds is not None:
         if numpy.ma.isMA(zfactor_bounds):
             zfactor_bounds = numpy.ascontiguousarray(zfactor_bounds.filled())
@@ -525,9 +535,9 @@ def zfactor(zaxis_id,zfactor_name,units="",axis_ids=None,type=None,zfactor_value
             zfactor_bounds = numpy.ascontiguousarray(zfactor_bounds)
         elif not isinstance(zfactor_bounds, numpy.ndarray):
             raise Exception, "Error could not convert zfactor_bounds to a numpy array"
-        if numpy.rank(zfactor_bounds)>2:
+        if numpy.ndim(zfactor_bounds)>2:
             raise Exception, "error zfactor_bounds must be rank 2 at most"
-        elif numpy.rank(zfactor_bounds)==2:
+        elif numpy.ndim(zfactor_bounds)==2:
             if zfactor_bounds.shape[1]!=2:
                 raise Exception, "error zfactor_bounds' 2nd dimension must be of length 2"
             bnds =[]
@@ -568,7 +578,7 @@ def write(var_id,data,ntimes_passed=None,file_suffix="",time_vals=None,time_bnds
         data = numpy.ascontiguousarray(data.filled())
     elif has_cdms2 and cdms2.isVariable(data):
         if time_vals is None:
-            time_vals = data.getTime() 
+            time_vals = data.getTime()
         data = numpy.ascontiguousarray(data.filled())
     elif isinstance(data,(list,tuple)):
         data = numpy.ascontiguousarray(data)
@@ -601,7 +611,7 @@ def write(var_id,data,ntimes_passed=None,file_suffix="",time_vals=None,time_bnds
         if not type in ['f','d','i','l']:
             raise Exception, "Error time_vals type must one of: 'f','d','i','l', please convert first"
         time_vals=time_vals.astype("d")
-       
+
 
     if ntimes_passed is None:
         if time_vals is None:
@@ -627,7 +637,7 @@ def write(var_id,data,ntimes_passed=None,file_suffix="",time_vals=None,time_bnds
         if goodshape[i]!=0:
             if sh[j]!=goodshape[i]:
                 if goodshape[i]!=1:
-                    raise Exception,"error your data shape (%s) does not match the expect variable shape (%s)" % (str(osh),str(ogoodshape))
+                    raise Exception,"Error: your data shape (%s) does not match the expected variable shape (%s)\nCheck your variable dimensions before caling cmor_write" % (str(osh),str(ogoodshape))
             j+=1
         elif ntimes_passed!=1:
             j+=1
@@ -644,16 +654,16 @@ def write(var_id,data,ntimes_passed=None,file_suffix="",time_vals=None,time_bnds
             time_bnds = numpy.ascontiguousarray(time_bnds.filled())
         elif has_cdms2 and cdms2.isVariable(time_bnds):
             if time_vals is None:
-                time_vals = time_bnds.getTime() 
+                time_vals = time_bnds.getTime()
             time_bnds = numpy.ascontiguousarray(time_bnds.filled())
         elif isinstance(time_bnds,(list,tuple)):
             time_bnds = numpy.ascontiguousarray(time_bnds)
         elif not isinstance(time_bnds, numpy.ndarray):
             raise Exception, "Error could not convert time_bnds to a numpy array"
 
-        if numpy.rank(time_bnds)>2:
+        if numpy.ndim(time_bnds)>2:
             raise Exception, "bounds rank cannot be greater than 2"
-        elif numpy.rank(time_bnds)==2:
+        elif numpy.ndim(time_bnds)==2:
             if time_bnds.shape[1]!=2:
                 raise Exception, "error time_bnds' 2nd dimension must be of length 2"
             bnds =[]
@@ -664,7 +674,7 @@ def write(var_id,data,ntimes_passed=None,file_suffix="",time_vals=None,time_bnds
                 bnds = time_bnds.ravel()
             time_bnds=numpy.array(bnds)
         else: # ok it is a rank 1!
-            if numpy.rank(time_vals)==0:
+            if numpy.ndim(time_vals)==0:
                 ltv=1
             else:
                 ltv=len(time_vals)
@@ -687,7 +697,7 @@ def write(var_id,data,ntimes_passed=None,file_suffix="",time_vals=None,time_bnds
     if not type in ['f','d','i','l']:
         raise Exception, "Error data type must one of: 'f','d','i','l', please convert first"
 
-    return _cmor.write(var_id,data,type,file_suffix,ntimes_passed,time_vals,time_bnds,store_with)
+    return _cmor.write(var_id,data,type,ntimes_passed,time_vals,time_bnds,store_with)
 
 def _check_time_bounds_contiguous(time_bnds):
     '''
@@ -749,83 +759,16 @@ def load_table(table):
 ##         raise Exception, "Error, the table you specified (%s) does not exists" % table
     return _cmor.load_table(table)
 
-def dataset(experiment_id,institution,source,calendar,outpath='.',realization=1,contact="",history="",comment="",references="",leap_year=0,leap_month=0,month_lengths=None,model_id="",forcing="",initialization_method=None,physics_version=None,institute_id="",parent_experiment_id="",branch_time=None,parent_experiment_rip=""):
-    """ Initialize a cmor dataset 
+def dataset_json(rcfile):
+    """ load dataset JSON file
     Usage:
-    dataset(experiment_id,institution,source,outpath='.',calendar=None,realization=None,contact=None,history="",comment="",references="",leap_year=None,leap_month=None,month_lengths=None,model_id="",forcing="",initialization_method=None,physics_version=None,institute_id="",parent_experiment_id="",branch_time=None,parent_experiment_rip="")
+    dataset_json(rcfile)
     """
-
-    if isinstance(calendar,int):
-        if has_cdtime: # put this in a try loop in case cdtime is not available on the system 
-            if calendar == cdtime.Calendar360:
-                calendar = "360_day"
-            elif calendar == cdtime.ClimCalendar:
-                calendar = "clim"
-            elif calendar == cdtime.DefaultCalendar:
-                calendar = "standard"
-            elif calendar == cdtime.GregorianCalendar:
-                calendar = "proleptic_gregorian"
-            elif calendar == cdtime.JulianCalendar:
-                calendar = "julian"
-            elif calendar == cdtime.MixedCalendar:
-                calendar= "standard"
-            elif calendar == cdtime.NoLeapCalendar:
-                calendar = "noleap"
-            elif calendar == cdtime.StandardCalendar:
-                calendar = "proleptic_gregorian"
-            elif calendar == cdtime.ClimLeapCalendar:
-                calendar = "climleap"
-    elif calendar is None:
-        calendar ="none"
-                
-    for st in [outpath,experiment_id,institution,source,contact,history,comment,references,model_id,forcing,institute_id,parent_experiment_id,parent_experiment_rip]:
-        if not isinstance(st,str):
-            for o in dir():
-                if locals()[o] is st:
-                    raise Exception, "Error argument %s must be a string" % o
-
-    calendar = calendar.lower()
-    
-    for i in [realization,leap_year,leap_month]:
-        if not isinstance(i,int):
-            for o in dir():
-                if locals()[o] is i:
-                    raise Exception, "Error argument %s must be an integer" % o
-    if isinstance(month_lengths,(list,tuple)):
-        month_lengths = numpy.array(month_lengths)
-    elif has_cdms2 and cdms2.isVariable(month_lengths):
-        month_lengths = month_lengths.filled()
-    elif isinstance(month_lengths,(numpy.ma.core.MaskedArray)):
-        month_lengths = month_lengths.filled()
-    elif has_oldma and isinstance(month_lengths,numpy.oldnumeric.ma.MaskedArray):
-        month_lengths = month_lengths.filled()
-        
-    if isinstance(month_lengths,numpy.ndarray):
-        if not numpy.rank(month_lengths)==1:
-            raise Exception, "Error month_lengths must be 1D"
-        if len(month_lengths)!=12:
-            raise Exception, "Error month_lengths must have 12 elements exactly"
-        months_lengths = numpy.ascontiguousarray(month_lengths)
-    elif month_lengths is not None:
-        raise Exception, "Error month_lengths must be a 12 elts array or list"
-    if initialization_method is not None:
-        if not isinstance(initialization_method,int):
-            raise Exception, "initialization_method must be an int"
-    else:
-        initialization_method=0
-    if physics_version is not None:
-        if not isinstance(physics_version,int):
-            raise Exception, "physics_version must be an int"
-    else:
-        physics_version=0
-
-    if branch_time is not None:
-        if not isinstance(branch_time,(float,int,numpy.float,numpy.float32,numpy.int,numpy.int32)):
-            raise Exception,"branch_time must be a float"
-        else:
-            branch_time=float(branch_time)
-
-    return _cmor.dataset(outpath,experiment_id,institution,source,calendar,realization,contact,history,comment,references,leap_year,leap_month,month_lengths,model_id,forcing,initialization_method,physics_version,institute_id,parent_experiment_id,branch_time,parent_experiment_rip)
+    if not isinstance(rcfile,str):
+        raise Exception, "Error, must pass a string"
+##     if not os.path.exists(table):
+##         raise Exception, "Error, the table you specified (%s) does not exists" % table
+    return _cmor.dataset_json(rcfile)
 
 def set_table(table):
     if not isinstance(table,int):
@@ -854,7 +797,7 @@ def close(var_id=None,file_name=False, preserve=False):
             return _cmor.close(var_id,0,1)
         else:
             return _cmor.close(var_id,1,1)
-        
+
 
 def set_cur_dataset_attribute(name,value):
     """Sets an attribute onto the current cmor dataset
@@ -896,7 +839,7 @@ def get_cur_dataset_attribute(name):
         return _cmor.get_cur_dataset_attribute(name)
     else:
         return None
-    
+
 def set_variable_attribute(var_id,name,value):
     """Sets an attribute onto a cmor variable
     Usage:
@@ -912,6 +855,22 @@ def set_variable_attribute(var_id,name,value):
         val = str(value)
     return _cmor.set_variable_attribute(var_id,name,val)
 
+def set_deflate(var_id,shuffle,deflate,deflate_level):
+    """Sets shuffle/deflate on a cmor variable
+    Usage:
+      cmor.set_deflate(var_id, shuffle, deflate, deflate_level)
+    Where:
+      var_id: is cmor variable id
+      shuffle: if true, turn on netCDF the shuffle filter
+      deflate: if true, turn on the deflate filter at the level
+               specified by the deflate_level parameter
+      deflate_level: if the deflate parameter is non-zero.
+                     Set the deflate value. Must be between 0 and 9
+
+    """
+
+    return _cmor.set_deflate(var_id, shuffle, deflate, deflate_level)
+
 def has_variable_attribute(var_id,name):
     """determines if the a cmor variable has an attribute
     Usage:
@@ -942,14 +901,8 @@ def get_variable_attribute(var_id,name):
         return _cmor.get_variable_attribute(var_id,name)
     else:
         return None
-    
-    
-def create_output_path(varid):
-    """returns the output path where a variable would be stored, given a varid (as returned by a call to cmor.variable)
-    Usage:
-      path = create_output_path(var_id)
-    Where:
-      var_id : id to variable as returned by a call to variable(...)
-    Returns: the path where the file will be created
-    """
-    return _cmor.create_output_path(varid)
+
+def get_final_filename():
+   """ Retrieve renamed file after cmor.close() has been called.  This is useful to reopen the file in the same program.
+   """
+   return _cmor.get_final_filename()
