@@ -37,7 +37,7 @@ CONTAINS
     END DO
           plevs = (/100000., 92500., 85000., 70000.,&
        60000., 50000., 40000., 30000., 25000., 20000.,&
-       15000., 10000., 7000., 5000., 3000., 2000., 1000. /)
+       15000., 10000., 7000., 5000., 3000., 2000., 1000., 500., 100./)
 
     RETURN
   END SUBROUTINE read_coords
@@ -111,10 +111,10 @@ PROGRAM ipcc_test_code
   INTEGER, PARAMETER :: lon = 4       ! number of longitude grid cells  
   INTEGER, PARAMETER :: lat = 3       ! number of latitude grid cells
   INTEGER, PARAMETER :: lev = 5       ! number of standard pressure levels
-  INTEGER, PARAMETER :: lev2 = 17       ! number of standard pressure levels
+  INTEGER, PARAMETER :: lev2 = 19       ! number of standard pressure levels
   INTEGER, PARAMETER :: n2d = 4       ! number of IPCC Table A1a fields to be
                                       !     output.
-  INTEGER, PARAMETER :: n3d = 4       ! number of IPCC Table A1c fields to 
+  INTEGER, PARAMETER :: n3d = 1       ! number of IPCC Table A1c fields to 
                                       !     be output.  
 
   !   Tables associating the user's variables with IPCC standard output 
@@ -128,14 +128,14 @@ PROGRAM ipcc_test_code
 
                                 ! My variable names for IPCC Table A1c fields
   CHARACTER (LEN=5), DIMENSION(n3d) :: &
-                                 varin3d=(/'CLOUD', 'tro3 ', 'U    ', 'T    '/)
+                                 varin3d=(/'tro3 '/)
 
                                 ! Units appropriate to my data
   CHARACTER (LEN=5), DIMENSION(n3d) :: &
-                                  units3d=(/ '%    ', '1e-9 ',  'm s-1',   'K    '  /)
+                                  units3d=(/ '1e-9 '/)
 
                      ! Corresponding IPCC Table A1c entry (variable name) 
-  CHARACTER (LEN=4), DIMENSION(n3d) :: entry3d = (/ 'cl  ', 'tro3', 'ua  ', 'ta  ' /)
+  CHARACTER (LEN=4), DIMENSION(n3d) :: entry3d = (/ 'tro3' /)
 
                                 ! My variable names for IPCC Table A1a fields
   CHARACTER (LEN=8), DIMENSION(n2d) :: &
@@ -175,7 +175,7 @@ PROGRAM ipcc_test_code
   REAL :: p0
   REAL, DIMENSION(lev+1) :: a_coeff_bnds
   REAL, DIMENSION(lev+1) :: b_coeff_bnds
-  INTEGER :: ilon, ilat, ipres, ilev, itim, ilon2,ilat2,itim2
+  INTEGER :: ilon, ilat, ipres, ilev, itim, ilon2,ilat2,itim2, itim3
   double precision bt
 
   !  Other variables:
@@ -214,34 +214,12 @@ PROGRAM ipcc_test_code
   !   experiment conditions, and provide information to be included as 
   !   attributes in all CF-netCDF files written as part of this dataset.
 
-  error_flag = cmor_dataset(                                   &
-       outpath='Test',                                         &
-       experiment_id='abrupt 4XCO2',           &
-       institution=                                            &
-       'GICC (Generic International Climate Center, ' //       &
-       'Geneva, Switzerland)',                                 &
-       source='GICCM1 (2002): ' //                             &
-       'atmosphere:  GICAM3 (gicam_0_brnchT_itea_2, T63L32); '// &
-       'ocean: MOM (mom3_ver_3.5.2, 2x3L15); '             //  &
-       'sea ice: GISIM4; land: GILSM2.5',                      &
-       calendar='360_day',                                      &
-       realization=1,                                          &
-       history='Output from archive/giccm_03_std_2xCO2_2256.', &
-       comment='Equilibrium reached after 30-year spin-up ' // &
-       'after which data were output starting with nominal '// &
-       'date of January 2030',                                 &
-       references='Model described by Koder and Tolkien ' //   &
-       '(J. Geophys. Res., 2001, 576-591).  Also '        //   &
-       'see http://www.GICC.su/giccm/doc/index.html '     //   &
-       ' 2XCO2 simulation described in Dorkey et al. '    //   &
-       '(Clim. Dyn., 2003, 323-357.)', model_id="GICCM1", &
-       forcing='TO',contact="Barry Bonds",institute_id="PCMDI",&
-       parent_experiment_rip="N/A",parent_experiment_id="N/A",branch_time=bt)
+  error_flag = cmor_dataset_json("Test/common_user_input.json")
   
   !  Define all axes that will be needed
   
   ilat = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
+       table='Tables/CMIP6_Amon.json',        &
        table_entry='latitude',       &
        units='degrees_north',        &  
        length=lat,                   &
@@ -249,7 +227,7 @@ PROGRAM ipcc_test_code
        cell_bounds=bnds_lat)        
       
   ilon = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
+       table='Tables/CMIP6_Amon.json',        &
        table_entry='longitude',      &
        length=lon,                   &
        units='degrees_east',         &
@@ -257,7 +235,7 @@ PROGRAM ipcc_test_code
        cell_bounds=bnds_lon)      
         
   ilat2 = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',        &
+       table='Tables/CMIP6_Lmon.json',        &
        table_entry='latitude',       &
        units='degrees_north',        &  
        length=lat,                   &
@@ -265,7 +243,7 @@ PROGRAM ipcc_test_code
        cell_bounds=bnds_lat)        
       
   ilon2 = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',        &
+       table='Tables/CMIP6_Lmon.json',        &
        table_entry='longitude',      &
        length=lon,                   &
        units='degrees_east',         &
@@ -275,8 +253,8 @@ PROGRAM ipcc_test_code
 
 print*, 'Test Code:',lev,':',plevs
   ipres = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
-       table_entry='plevs',       &
+       table='Tables/CMIP6_Amon.json',        &
+       table_entry='plev19',       &
        units='Pa',                   &
        length=lev2,                   &
        coord_vals=plevs)
@@ -285,25 +263,33 @@ print*, 'Test Code:',lev,':',plevs
   !   cmor_write (later, below).
 
   itim = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
+       table='Tables/CMIP6_Amon.json',        &
        table_entry='time',           &
        units='days since 2030-1-1',  &
        length=ntimes,                &
        interval='1 month')
   
   itim2 = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',        &
+       table='Tables/CMIP6_Lmon.json',        &
        table_entry='time',           &
        units='days since 2030-1-1',  &
        length=ntimes,                &
        interval='1 month')
+
+  itim3 = cmor_axis(  &
+       table='Tables/CMIP6_Amon.json',        &
+       table_entry='time',           &
+       units='days since 2030-1-1',  &
+       length=ntimes,                &
+       interval='1 month')
+  
   
   !  define model eta levels
   zlevs = (/ 0.1, 0.3, 0.55, 0.7, 0.9 /)
   zlev_bnds=(/ 0.,.2, .42, .62, .8, 1. /)
 
   ilev = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
+       table='Tables/CMIP6_Amon.json',        &
        table_entry='standard_hybrid_sigma',       &
        units='1',  &
        length=lev,                   &
@@ -348,26 +334,13 @@ print*, 'Test Code:',lev,':',plevs
   !    (appearing in IPCC table A1c)
 
   var3d_ids(1) = cmor_variable(    &
-       table='Tables/CMIP5_Amon',      &
+       table='Tables/CMIP6_Amon.json',      &
        table_entry=entry3d(1),     &
        units=units3d(1),           &
-       axis_ids=(/ ilev, ilon, ilat, itim /),  &
+       axis_ids=(/ ipres, ilon, ilat, itim3 /),  &
        missing_value=1.0e28, &
        original_name=varin3d(1))
   
-  !  Define variables appearing in IPCC table A1c that are a function of pressure
-  !         (3-d variables)
-  
-  DO m=2,n3d
-     var3d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Amon',      &
-          table_entry=entry3d(m),     &
-          units=units3d(m),           &
-          axis_ids=(/ ipres, ilon, ilat, itim /), &
-          missing_value=1.0e28,       &
-          original_name=varin3d(m))
-  ENDDO
-  
 
   !  Define variables appearing in IPCC table A1a (2-d variables)
   
@@ -375,7 +348,7 @@ print*, 'Test Code:',lev,':',plevs
      print*, m, entry2d(m)
      if (m.ne.3) then
      var2d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Amon',      &
+          table='Tables/CMIP6_Amon.json',      &
           table_entry=entry2d(m),     & 
           units=units2d(m),           & 
           axis_ids=(/ ilon, ilat, itim /), &
@@ -384,7 +357,7 @@ print*, 'Test Code:',lev,':',plevs
           original_name=varin2d(m))   
   else
      var2d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Lmon',      &
+          table='Tables/CMIP6_Lmon.json',      &
           table_entry=entry2d(m),     & 
           units=units2d(m),           & 
           axis_ids=(/ ilon2, ilat2, itim2 /), &
@@ -429,47 +402,39 @@ print*, 'Test Code:',lev,':',plevs
          time_vals     = time,                                &
          time_bnds     = bnds_time   )
 
-    call read_2d_input_files(it, varin2d(4), data2d)                  
-
-    error_flag = cmor_write(                                  &
-         var_id        = zfactor_id,                          &
-         data          = data2d,                              &
-         ntimes_passed = 1,                                   &
-         time_vals     = time,                                &
-         time_bnds     = bnds_time,                           &
-         store_with    = var3d_ids(1) )
-
     ! Cycle through the 3-d fields (stored on pressure levels), 
     ! and retrieve the requested variable and append each to the 
     ! appropriate netCDF file.
 
-    DO m=2,n3d
-        
-        ! The user must write the code that fills the arrays of data
-        ! that will be passed to CMOR.  The following line is simply a
-        ! a place-holder for the user's code, which should replace it.
-
-        call read_3d_input_files(it, varin3d(m), data3d)
-       
-        ! append a single time sample of data for a single field to 
-        ! the appropriate netCDF file.
-        
-        error_flag = cmor_write(                                  &
-             var_id        = var3d_ids(m),                        &
-             data          = data3d,                              &
-             ntimes_passed = 1,                                   &
-             time_vals     = time,                                &
-             time_bnds     = bnds_time  )
-
-        IF (error_flag < 0) THEN
-           ! write diagnostic messages to standard output device
-           write(*,*) ' Error encountered writing IPCC Table A1c ' &
-                // 'field ', entry3d(m), ', which I call ', varin3d(m)
-           write(*,*) ' Was processing time sample: ', time
-                      
-        END IF
-
-     END DO
+    !DO m=2,n3d
+    !    
+    !    ! The user must write the code that fills the arrays of data
+    !    ! that will be passed to CMOR.  The following line is simply a
+    !    ! a place-holder for the user's code, which should replace it.
+!
+!        call read_3d_input_files(it, varin3d(m), data3d)
+!       
+!        ! append a single time sample of data for a single field to 
+!        ! the appropriate netCDF file.
+!        
+!        print *, time
+!        print *, bnds_time
+!        error_flag = cmor_write(                                  &
+!             var_id        = var3d_ids(m),                        &
+!             data          = data3d,                              &
+!             ntimes_passed = 1,                                   &
+!             time_vals     = time,                                &
+!             time_bnds     = bnds_time  )
+!
+!        IF (error_flag < 0) THEN
+!           ! write diagnostic messages to standard output device
+!           write(*,*) ' Error encountered writing IPCC Table A1c ' &
+!                // 'field ', entry3d(m), ', which I call ', varin3d(m)
+!           write(*,*) ' Was processing time sample: ', time
+!                      
+!        END IF
+!
+!     END DO
      
      ! Cycle through the 2-d fields, retrieve the requested variable and 
      ! append each to the appropriate netCDF file.
