@@ -35,20 +35,9 @@ def mywrite(data = None, time_vals = None, append_to = None,cell_bounds=None):
                netcdf_file_action = mode,
                logfile = None)
 
-    cmor.dataset(
-        outpath = ipth,
-        experiment_id = "lgm",
-        institution = "PCMDI",
-        source = "GICCM1 2002",
-        institute_id="PCMDI",
-        calendar = "standard",
-        contact="Pablo Sandoval",
-        model_id="GICCM1",forcing="Nat",
-        parent_experiment_id="historical",
-        parent_experiment_rip="r1i3p2",
-        branch_time=3.14159)
+    cmor.dataset_json("Test/common_user_input.json")
 
-    cmor.load_table("Tables/CMIP5_Amon")
+    cmor.load_table("Tables/CMIP6_Amon.json")
 
     dlat = 180/nlat
     dlon = 360./nlon
@@ -59,14 +48,14 @@ def mywrite(data = None, time_vals = None, append_to = None,cell_bounds=None):
 
     plevs = numpy.array([100000., 92500., 85000., 70000.,
                          60000., 50000., 40000., 30000., 25000., 20000.,
-                         15000., 10000., 7000., 5000., 3000., 2000., 1000.])
+                         15000., 10000., 7000., 5000., 3000., 2000., 1000., 500., 100.])
 
     itim = cmor.axis(table_entry='time',units='month since 2008')
     #itim = cmor.axis(table_entry='time',units='month since 2008',coord_vals=numpy.arange(0,12,1))
     ilat = cmor.axis(table_entry='latitude',coord_vals=lats,units='degrees_north',cell_bounds=bnds_lat)
     ilon = cmor.axis(table_entry='longitude',coord_vals=lons,units='degrees_east',cell_bounds=bnds_lon)
     print 'so far',itim,ilat,ilon
-    ilev = cmor.axis(table_entry="plevs",coord_vals=plevs,units="Pa")
+    ilev = cmor.axis(table_entry="plev19",coord_vals=plevs,units="Pa")
 
     iv = cmor.variable(table_entry='ta',axis_ids=numpy.array((itim,ilev,ilat,ilon)),units='K')
 
@@ -86,7 +75,7 @@ def mywrite(data = None, time_vals = None, append_to = None,cell_bounds=None):
 
 
 ntime = 12
-data = numpy.random.random((ntime,17,nlat,nlon))+280.
+data = numpy.random.random((ntime,19,nlat,nlon))+280.
 
 
 f1 = mywrite(data = data[:6], time_vals = numpy.arange(0,6,1),cell_bounds=numpy.arange(0,7,1))
