@@ -20,21 +20,14 @@ levs=numpy.array(levs)
 
 print levs
 
-ipth="Test"
-cmor.setup(inpath=ipth,
+cmor.setup(inpath="Tables",
            set_verbosity=cmor.CMOR_NORMAL,
            netcdf_file_action = cmor.CMOR_REPLACE,
            logfile = None)
 
-cmor.dataset(
-    outpath = ipth,
-    experiment_id = "present-day control experiment",
-    institution = "PCMDI",
-    source = "PCMDI",
-    calendar = "standard",
-    model_id="pcmdi-09a",forcing="forcing")
+cmor.dataset_json("Test/common_user_input.json")
 
-cmor.load_table("python_test_table_A")
+cmor.load_table("Test/python_test_table_A")
 
 nlat = 90
 dlat = 180/nlat
@@ -52,6 +45,7 @@ itim = cmor.axis(table_entry='time',coord_vals=numpy.arange(0,ntime,1),units='mo
 ilat = cmor.axis(table_entry='latitude',coord_vals=lats,units='degrees_north')
 ilon = cmor.axis(table_entry='longitude',coord_vals=lons,units='degrees_east')
 print 'so far',itim,ilat,ilon
+print bnds_req
 ilev = cmor.axis(table_entry="pressure2",coord_vals=levs,cell_bounds=bnds_req,units="Pa")
 
 iv = cmor.variable(table_entry='ta',axis_ids=numpy.array((itim,ilev,ilat,ilon)),units='K')
