@@ -1,7 +1,6 @@
 from test_python_common import * # common subroutines
 import cmor._cmor
 import os
-
 pth = os.path.split(os.path.realpath(os.curdir))
 if pth[-1]=='Test':
     ipth = opth = '.'
@@ -13,25 +12,13 @@ myaxes2=numpy.zeros(9,dtype='i')
 myvars=numpy.zeros(9,dtype='i')
 
 cmor._cmor.setup(ipth,cmor.CMOR_REPLACE,cmor.CMOR_NORMAL,cmor.CMOR_EXIT_ON_MAJOR,"",1);
-cmor._cmor.dataset( \
-    ipth,\
-    "lgm",\
-    "GICC (Generic International Climate Center, Geneva, Switzerland)",\
-    "GICCM1 (2002): atmosphere:  GICAM3 (gicam_0_brnchT_itea_2, T63L32); ocean: MOM (mom3_ver_3.5.2, 2x3L15); sea ice: GISIM4; land: GILSM2.5",\
-    "standard",\
-    1,\
-    "Rusty Koder (koder@middle_earth.net)",\
-    "Output from archive/giccm_03_std_2xCO2_2256.",\
-    "Equilibrium reached after 30-year spin-up after which data were output starting with nominal date of January 2030",\
-    "Model described by Koder and Tolkien (J. Geophys. Res., 2001, 576-591).  Also see http://www.GICC.su/giccm/doc/index.html  2XCO2 simulation described in Dorkey et al. '(Clim. Dyn., 2003, 323-357.)",\
-    0,\
-    0,\
-    None,"GICCM1","Nat",0,0,"PCMDI","N/A",0,"r1i1p1")
+cmor.dataset_json("Test/common_user_input.json")
+#cmor.dataset_json("Test/common_user_input.json")
 
 tables=[]
-a = cmor._cmor.load_table("Tables/CMIP5_Omon")
+a = cmor._cmor.load_table("Tables/CMIP6_Omon.json")
 tables.append(a)
-tables.append(cmor._cmor.load_table("Tables/CMIP5_Amon"))
+tables.append(cmor._cmor.load_table("Tables/CMIP6_Amon.json"))
 print 'Tables ids:',tables
 
 
@@ -46,7 +33,7 @@ myaxes[1] = cmor._cmor.axis(id,units,lat,alats,'d',bnds_lat,2,interval)
 id="longitude"
 units="degrees_east"
 myaxes[2] = cmor._cmor.axis(id,units,lon,alons,'d',bnds_lon,2,interval)
-id="plevs"
+id="plev19"
 units="Pa"
 print plevs.astype("d")
 myaxes[3] = cmor._cmor.axis(id,units,lev2,plevs.astype("d"),'d',None,0,interval)
@@ -78,11 +65,11 @@ myaxes2[3] = myaxes[2];
 print 'ok doing the vars thing'
 myvars[0] = cmor._cmor.variable(entry2d[0],units2d[0],3,myaxes,'d',None,dtmp2,positive2d[0],varin2d[0],"no history","no future")
 print 'vars 2'
-myvars[1] = cmor._cmor.variable(entry3d[2],units3d[2],4,myaxes2,'d',None,dtmp2,"",varin3d[2],"no history","no future")
+myvars[1] = cmor._cmor.variable(entry3d[2],units3d[2],4,myaxes2,'d',None,dtmp2,"down",varin3d[2],"no history","no future")
 print 'vars 2'
 
 myaxes2[1] = myaxes[4];
-myvars[2] = cmor._cmor.variable(entry3d[0],units3d[0],4,myaxes2,'d',None,dtmp2,"",varin3d[0],"no history","no future")
+myvars[2] = cmor._cmor.variable(entry3d[0],units3d[0],4,myaxes2,'d',None,dtmp2,"down",varin3d[0],"no history","no future")
 
 print 'vars 2'
 
@@ -115,6 +102,6 @@ cmor.set_table(tables[1])
 for i in range(ntimes):
     data2d = read_2d_input_files(i, varin2d[0], lat,lon)
     print 'writing time',i,data2d.shape,data2d,numpy.average(data2d)
-    cmor._cmor.write(myvars[0],numpy.ravel(data2d),data2d.dtype.char,"",1,None,None,None);
+    cmor._cmor.write(myvars[0],numpy.ravel(data2d),data2d.dtype.char,1,None,None,None);
 
 cmor._cmor.close(None,0,0)
